/**
 * Enhanced Seccomp SW_64 Syscall Table
 *
 * Copyright (c) 2013 Red Hat <pmoore@redhat.com>
 * Author: Paul Moore <paul@paul-moore.com>
 */

/*
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of version 2.1 of the GNU Lesser General Public License as
 * published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, see <http://www.gnu.org/licenses>.
 */

#include <string.h>

#include <seccomp.h>

#include "arch.h"
#include "arch-sw_64.h"

#define __SCMP_NR_OABI_SYSCALL_BASE	0x900000

/* NOTE: we currently only support the SW_64 EABI, more info at the URL below:
 *       -> http://wiki.embeddedarm.com/wiki/EABI_vs_OABI */
#if 1
#define __SCMP_NR_BASE			0
#else
#define __SCMP_NR_BASE			__SCMP_NR_OABI_SYSCALL_BASE
#endif

#define __PNR_afs_syscall 	338
/* NOTE: based on Linux v5.4-rc4 */
const struct arch_syscall_def sw_64_syscall_table[] = { \
	/* NOTE: sw_64_sync_file_range() and sync_file_range2() share values */
	{ "gethostname", (__SCMP_NR_BASE + 87) },
	{ "osf_sigprocmask", (__SCMP_NR_BASE + 48) },
	{ "getxpid", (__SCMP_NR_BASE + 20) },
	{ "getxuid", (__SCMP_NR_BASE + 24) },
	{ "getxgid", (__SCMP_NR_BASE + 47) },
	{ "_sysctl", (__SCMP_NR_BASE + 319) },
	{ "accept", (__SCMP_NR_BASE + 99) },
	{ "accept4", (__SCMP_NR_BASE + 502) },
	{ "access", (__SCMP_NR_BASE + 33) },
	{ "acct", (__SCMP_NR_BASE + 51) },
	{ "add_key", (__SCMP_NR_BASE + 439) },
	{ "adjtimex", (__SCMP_NR_BASE + 366) },
	{ "afs_syscall", __PNR_afs_syscall },
	{ "arm_fadvise64_64", (__SCMP_NR_BASE + 270) },
	{ "arm_sync_file_range", (__SCMP_NR_BASE + 341) },
	{ "bdflush", (__SCMP_NR_BASE + 300) },
	{ "bind", (__SCMP_NR_BASE + 104) },
	{ "bpf", (__SCMP_NR_BASE + 170) },
	{ "brk", (__SCMP_NR_BASE + 17) },
	{ "capget", (__SCMP_NR_BASE + 368) },
	{ "capset", (__SCMP_NR_BASE + 369) },
	{ "chdir", (__SCMP_NR_BASE + 12) },
	{ "chmod", (__SCMP_NR_BASE + 15) },
	{ "chown", (__SCMP_NR_BASE + 16) },
	{ "chroot", (__SCMP_NR_BASE + 61) },
	{ "clock_adjtime", (__SCMP_NR_BASE + 499) },
	{ "clock_getres", (__SCMP_NR_BASE + 421) },
	{ "clock_gettime", (__SCMP_NR_BASE + 420) },
	{ "clock_nanosleep", (__SCMP_NR_BASE + 422) },
	{ "clock_settime", (__SCMP_NR_BASE + 419) },
	{ "clone", (__SCMP_NR_BASE + 312) },
	{ "close", (__SCMP_NR_BASE +  6) },
	{ "connect", (__SCMP_NR_BASE + 98) },
	{ "copy_file_range", (__SCMP_NR_BASE + 515) },
	{ "delete_module", (__SCMP_NR_BASE + 308) },
	{ "dup", (__SCMP_NR_BASE + 41) },
	{ "dup2", (__SCMP_NR_BASE + 90) },
	{ "dup3", (__SCMP_NR_BASE + 487) },
	{ "epoll_create", (__SCMP_NR_BASE + 407) },
	{ "epoll_create1", (__SCMP_NR_BASE + 486) },
	{ "epoll_ctl", (__SCMP_NR_BASE + 408) },
	{ "epoll_pwait", (__SCMP_NR_BASE + 474) },
	{ "epoll_wait", (__SCMP_NR_BASE + 409) },
	{ "eventfd", (__SCMP_NR_BASE + 478) },
	{ "eventfd2", (__SCMP_NR_BASE + 485) },
	{ "execve", (__SCMP_NR_BASE + 59) },
	{ "execveat", (__SCMP_NR_BASE + 513) },
	{ "exit", (__SCMP_NR_BASE +  1) },
	{ "exit_group", (__SCMP_NR_BASE + 405) },
	{ "faccessat", (__SCMP_NR_BASE + 462) },
	{ "fadvise64", (__SCMP_NR_BASE+413) },
	{ "fallocate", (__SCMP_NR_BASE + 480) },
	{ "fanotify_init", (__SCMP_NR_BASE + 494) },
	{ "fanotify_mark", (__SCMP_NR_BASE + 495) },
	{ "fchdir", (__SCMP_NR_BASE + 13) },
	{ "fchmod", (__SCMP_NR_BASE + 124) },
	{ "fchmodat", (__SCMP_NR_BASE + 461) },
	{ "fchown", (__SCMP_NR_BASE + 123) },
	{ "fchownat", (__SCMP_NR_BASE + 453) },
	{ "fcntl", (__SCMP_NR_BASE + 92) },
	{ "fdatasync", (__SCMP_NR_BASE + 447) },
	{ "fgetxattr", (__SCMP_NR_BASE + 387) },
	{ "finit_module", (__SCMP_NR_BASE + 507) },
	{ "flistxattr", (__SCMP_NR_BASE + 390) },
	{ "flock", (__SCMP_NR_BASE + 131) },
	{ "fork", (__SCMP_NR_BASE +  2) },
	{ "fremovexattr", (__SCMP_NR_BASE + 393) },
	{ "fsetxattr", (__SCMP_NR_BASE + 384) },
	{ "fstat", (__SCMP_NR_BASE + 91) },
	{ "fstat64", (__SCMP_NR_BASE + 427) },
	{ "fstatat64", (__SCMP_NR_BASE + 455) },
	{ "fstatfs", (__SCMP_NR_BASE + 329) },
	{ "fstatfs64", (__SCMP_NR_BASE + 230) },
	{ "fsync", (__SCMP_NR_BASE + 95) },
	{ "ftruncate", (__SCMP_NR_BASE + 130) },
	{ "futex", (__SCMP_NR_BASE + 394) },
	{ "futimesat", (__SCMP_NR_BASE + 454) },
	{ "get_mempolicy", (__SCMP_NR_BASE + 430) },
	{ "get_robust_list", (__SCMP_NR_BASE + 467) },
	{ "getcpu", (__SCMP_NR_BASE + 473) },
	{ "getcwd", (__SCMP_NR_BASE + 367) },
	{ "getdents", (__SCMP_NR_BASE + 305) },
	{ "getdents64", (__SCMP_NR_BASE + 377) },
	{ "getegid", (__SCMP_NR_BASE + 179) },
	{ "getegid32", (__SCMP_NR_BASE + 202) },
	{ "geteuid", (__SCMP_NR_BASE + 177) },
	{ "geteuid32", (__SCMP_NR_BASE + 201) },
	{ "getgid", (__SCMP_NR_BASE + 178) },
	{ "getgid32", (__SCMP_NR_BASE + 200) },
	{ "getgroups", (__SCMP_NR_BASE + 79) },
	{ "getgroups32", (__SCMP_NR_BASE + 205) },
	{ "getitimer", (__SCMP_NR_BASE + 361) },
	{ "getpeername", (__SCMP_NR_BASE + 141) },
	{ "getpgid", (__SCMP_NR_BASE + 233) },
	{ "getpgrp", (__SCMP_NR_BASE + 63) },
	{ "getpid", (__SCMP_NR_BASE + 174) },
	{ "getppid", (__SCMP_NR_BASE + 175) },
	{ "getpriority", (__SCMP_NR_BASE + 100) },
	{ "getrandom", (__SCMP_NR_BASE + 511) },
	{ "getresgid", (__SCMP_NR_BASE + 372) },
	{ "getresuid", (__SCMP_NR_BASE + 344) },
	{ "getrlimit",(__SCMP_NR_BASE + 144) },
	{ "getrusage", (__SCMP_NR_BASE + 364) },
	{ "getsid", (__SCMP_NR_BASE + 234) },
	{ "getsockname", (__SCMP_NR_BASE + 150) },
	{ "getsockopt", (__SCMP_NR_BASE + 118) },
	{ "gettid", (__SCMP_NR_BASE + 378) },
	{ "gettimeofday", (__SCMP_NR_BASE + 359) },
	{ "getuid", (__SCMP_NR_BASE + 176) },
	{ "getxattr", (__SCMP_NR_BASE + 385) },
	{ "init_module", (__SCMP_NR_BASE + 307) },
	{ "inotify_add_watch", (__SCMP_NR_BASE + 445) },
	{ "inotify_init", (__SCMP_NR_BASE + 444) },
	{ "inotify_init1", (__SCMP_NR_BASE + 489) },
	{ "inotify_rm_watch", (__SCMP_NR_BASE + 446) },
	{ "io_cancel", (__SCMP_NR_BASE + 402) },
	{ "io_destroy", (__SCMP_NR_BASE + 399) },
	{ "io_getevents", (__SCMP_NR_BASE + 400) },
	{ "io_pgetevents", (__SCMP_NR_BASE + 403) },
	{ "io_setup", (__SCMP_NR_BASE + 398) },
	{ "io_submit", (__SCMP_NR_BASE + 401) },
	{ "ioctl", (__SCMP_NR_BASE + 54) },
	{ "ioprio_get", (__SCMP_NR_BASE + 443) },
	{ "ioprio_set", (__SCMP_NR_BASE + 442) },
	{ "kcmp", (__SCMP_NR_BASE + 506) },
	{ "kexec_load", (__SCMP_NR_BASE + 448) },
	{ "keyctl", (__SCMP_NR_BASE + 441) },
	{ "kill", (__SCMP_NR_BASE + 37) },
	{ "lchown", (__SCMP_NR_BASE + 208) },
	{ "lgetxattr", (__SCMP_NR_BASE + 386) },
	{ "link", (__SCMP_NR_BASE +  9) },
	{ "linkat", (__SCMP_NR_BASE + 458) },
	{ "listen", (__SCMP_NR_BASE + 106) },
	{ "listxattr", (__SCMP_NR_BASE + 388) },
	{ "llistxattr", (__SCMP_NR_BASE + 389) },
	{ "flock", (__SCMP_NR_BASE + 131) },
	{ "lookup_dcookie", (__SCMP_NR_BASE + 406) },
	{ "lremovexattr", (__SCMP_NR_BASE + 392) },
	{ "lseek", (__SCMP_NR_BASE + 19) },
	{ "lsetxattr", (__SCMP_NR_BASE + 383) },
	{ "lstat", (__SCMP_NR_BASE + 68) },
	{ "lstat64", (__SCMP_NR_BASE + 426) },
	{ "madvise", (__SCMP_NR_BASE + 75) },
	{ "mbind", (__SCMP_NR_BASE + 429) },
	{ "membarrier",  (__SCMP_NR_BASE + 172) },
	{ "memfd_create", (__SCMP_NR_BASE + 512) },
	{ "migrate_pages", (__SCMP_NR_BASE + 449) },
	{ "mincore", (__SCMP_NR_BASE + 375) },
	{ "mkdir", (__SCMP_NR_BASE + 136) },
	{ "mkdirat", (__SCMP_NR_BASE + 451) },
	{ "mknod", (__SCMP_NR_BASE + 14) },
	{ "mknodat", (__SCMP_NR_BASE + 452) },
	{ "mlock", (__SCMP_NR_BASE + 314) },
	{ "mlock2", (__SCMP_NR_BASE + 173) },
	{ "mlockall", (__SCMP_NR_BASE + 316) },
	{ "mmap", (__SCMP_NR_BASE + 71)},
	{ "mount", (__SCMP_NR_BASE + 302) },
	{ "move_pages", (__SCMP_NR_BASE + 472) },
	{ "mprotect", (__SCMP_NR_BASE + 74) },
	{ "mq_getsetattr", (__SCMP_NR_BASE + 437) },
	{ "mq_notify", (__SCMP_NR_BASE + 436) },
	{ "mq_open", (__SCMP_NR_BASE + 432) },
	{ "mq_timedreceive", (__SCMP_NR_BASE + 435) },
	{ "mq_timedsend", (__SCMP_NR_BASE + 434) },
	{ "mq_unlink", (__SCMP_NR_BASE + 433) },
	{ "mremap", (__SCMP_NR_BASE + 341) },
	{ "msgctl", (__SCMP_NR_BASE + 200) },
	{ "msgget", (__SCMP_NR_BASE + 201) },
	{ "msgrcv", (__SCMP_NR_BASE + 202) },
	{ "msgsnd", (__SCMP_NR_BASE + 203) },
	{ "msync", (__SCMP_NR_BASE + 217) },
	{ "munlock", (__SCMP_NR_BASE + 315) },
	{ "munlockall", (__SCMP_NR_BASE + 317) },
	{ "munmap", (__SCMP_NR_BASE + 73) },
	{ "name_to_handle_at", (__SCMP_NR_BASE + 497) },
	{ "nanosleep", (__SCMP_NR_BASE + 340) },
	{ "open", (__SCMP_NR_BASE +  45) },
	{ "open_by_handle_at", (__SCMP_NR_BASE + 498) },
	{ "openat", (__SCMP_NR_BASE + 450) },
	{ "pciconfig_iobase", (__SCMP_NR_BASE + 376) },
	{ "pciconfig_read", (__SCMP_NR_BASE + 345) },
	{ "pciconfig_write", (__SCMP_NR_BASE + 346) },
	{ "perf_event_open", (__SCMP_NR_BASE + 493) },
	{ "personality", (__SCMP_NR_BASE + 324) },
	{ "pipe", (__SCMP_NR_BASE + 42) },
	{ "pipe2", (__SCMP_NR_BASE + 488) },
	{ "pivot_root", (__SCMP_NR_BASE + 374) },
	{ "poll", (__SCMP_NR_BASE + 94) },
	{ "ppoll", (__SCMP_NR_BASE + 464) },
	{ "prctl", (__SCMP_NR_BASE + 348) },
	{ "pread64", (__SCMP_NR_BASE + 349) },
	{ "preadv", (__SCMP_NR_BASE + 490) },
	{ "preadv2", (__SCMP_NR_BASE + 516) },
	{ "prlimit64", (__SCMP_NR_BASE + 496) },
	{ "process_vm_readv", (__SCMP_NR_BASE + 504) },
	{ "process_vm_writev", (__SCMP_NR_BASE + 505) },
	{ "pselect6", (__SCMP_NR_BASE + 463) },
	{ "ptrace", (__SCMP_NR_BASE + 26) },
	{ "pwrite64", (__SCMP_NR_BASE + 350) },
	{ "pwritev", (__SCMP_NR_BASE + 491) },
	{ "pwritev2", (__SCMP_NR_BASE + 517) },
	{ "quotactl", (__SCMP_NR_BASE + 148) },
	{ "read", (__SCMP_NR_BASE +  3) },
	{ "readahead", (__SCMP_NR_BASE + 379) },
	{ "readlink", (__SCMP_NR_BASE + 58) },
	{ "readlinkat", (__SCMP_NR_BASE + 460) },
	{ "readv", (__SCMP_NR_BASE + 120) },
	{ "reboot", (__SCMP_NR_BASE + 311) },
	{ "recv", (__SCMP_NR_BASE + 102) },
	{ "recvfrom", (__SCMP_NR_BASE + 125) },
	{ "recvmmsg", (__SCMP_NR_BASE + 479) },
	{ "recvmsg", (__SCMP_NR_BASE + 113) },
	{ "remap_file_pages", (__SCMP_NR_BASE + 410) },
	{ "removexattr", (__SCMP_NR_BASE + 391) },
	{ "rename", (__SCMP_NR_BASE + 128) },
	{ "renameat", (__SCMP_NR_BASE + 457) },
	{ "renameat2", (__SCMP_NR_BASE + 510) },
	{ "request_key", (__SCMP_NR_BASE + 440) },
	{ "restart_syscall", (__SCMP_NR_BASE +  412) },
	{ "rmdir", (__SCMP_NR_BASE + 137) },
	{ "rt_sigaction", (__SCMP_NR_BASE + 352) },
	{ "rt_sigpending", (__SCMP_NR_BASE + 354) },
	{ "rt_sigprocmask", (__SCMP_NR_BASE + 353) },
	{ "rt_sigqueueinfo", (__SCMP_NR_BASE + 356) },
	{ "rt_sigreturn", (__SCMP_NR_BASE + 351) },
	{ "rt_sigsuspend", (__SCMP_NR_BASE + 357) },
	{ "rt_sigtimedwait", (__SCMP_NR_BASE + 355) },
	{ "rt_tgsigqueueinfo", (__SCMP_NR_BASE + 492) },
	{ "sched_get_priority_max", (__SCMP_NR_BASE + 335) },
	{ "sched_get_priority_min", (__SCMP_NR_BASE + 336) },
	{ "sched_getaffinity", (__SCMP_NR_BASE + 396) },
	{ "sched_getattr", (__SCMP_NR_BASE + 509) },
	{ "sched_getparam", (__SCMP_NR_BASE + 331) },
	{ "sched_getscheduler", (__SCMP_NR_BASE + 333) },
	{ "sched_rr_get_interval", (__SCMP_NR_BASE + 337) },
	{ "sched_setaffinity", (__SCMP_NR_BASE + 395) },
	{ "sched_setattr", (__SCMP_NR_BASE + 508) },
	{ "sched_setparam", (__SCMP_NR_BASE + 330) },
	{ "sched_setscheduler", (__SCMP_NR_BASE + 332) },
	{ "sched_yield", (__SCMP_NR_BASE + 334) },
	{ "seccomp", (__SCMP_NR_BASE + 514) },
	{ "select", (__SCMP_NR_BASE + 358) },
	{ "semctl", (__SCMP_NR_BASE + 204) },
	{ "semget", (__SCMP_NR_BASE + 205) },
	{ "semop", (__SCMP_NR_BASE + 206) },
	{ "semtimedop", (__SCMP_NR_BASE + 423) },
	{ "send", (__SCMP_NR_BASE + 101) },
	{ "sendfile", (__SCMP_NR_BASE + 370) },
	{ "sendfile64", (__SCMP_NR_BASE + 370) },
	{ "sendmmsg", (__SCMP_NR_BASE + 503) },
	{ "sendmsg", (__SCMP_NR_BASE + 114) },
	{ "sendto", (__SCMP_NR_BASE + 133) },
	{ "set_mempolicy", (__SCMP_NR_BASE + 431) },
	{ "set_robust_list", (__SCMP_NR_BASE + 466) },
	{ "set_tid_address", (__SCMP_NR_BASE + 411) },
	{ "setdomainname", (__SCMP_NR_BASE + 166) },
	{ "setfsgid", (__SCMP_NR_BASE + 326) },
	{ "setfsuid", (__SCMP_NR_BASE + 325) },
	{ "setgid", (__SCMP_NR_BASE + 132) },
	{ "setgroups", (__SCMP_NR_BASE + 80) },
	{ "sethostname", (__SCMP_NR_BASE + 88) },
	{ "setitimer", (__SCMP_NR_BASE + 362) },
	{ "setns", (__SCMP_NR_BASE + 501) },
	{ "setpgid", (__SCMP_NR_BASE + 39) },
	{ "setpriority", (__SCMP_NR_BASE + 96) },
	{ "setregid", (__SCMP_NR_BASE + 127) },
	{ "setresgid", (__SCMP_NR_BASE + 371) },
	{ "setresuid", (__SCMP_NR_BASE + 343) },
	{ "setreuid", (__SCMP_NR_BASE + 126) },
	{ "setrlimit", (__SCMP_NR_BASE + 145) },
	{ "setsid", (__SCMP_NR_BASE + 147) },
	{ "setsockopt", (__SCMP_NR_BASE + 105) },
	{ "settimeofday", (__SCMP_NR_BASE + 360) },
	{ "setuid", (__SCMP_NR_BASE + 23) },
	{ "setxattr", (__SCMP_NR_BASE + 382) },
	{ "shmat", (__SCMP_NR_BASE + 209) },
	{ "shmctl", (__SCMP_NR_BASE + 210) },
	{ "shmdt", (__SCMP_NR_BASE + 211) },
	{ "shmget", (__SCMP_NR_BASE + 212) },
	{ "shutdown", (__SCMP_NR_BASE + 134) },
	{ "sigaction", (__SCMP_NR_BASE + 352) },
	{ "sigaltstack", (__SCMP_NR_BASE + 235) },
	{ "signalfd", (__SCMP_NR_BASE + 476) },
	{ "signalfd4", (__SCMP_NR_BASE + 484) },
	{ "sigpending", (__SCMP_NR_BASE + 52) },
	{ "sigprocmask", (__SCMP_NR_BASE + 353) },
	{ "sigreturn", (__SCMP_NR_BASE + 103) },
	{ "sigsuspend", (__SCMP_NR_BASE + 111) },
	{ "socket", (__SCMP_NR_BASE + 97) },
	{ "socketcall", (__SCMP_NR_BASE + 119) },
	{ "socketpair", (__SCMP_NR_BASE + 135) },
	{ "splice", (__SCMP_NR_BASE + 468) },
	{ "stat", (__SCMP_NR_BASE + 67) },
	{ "stat64", (__SCMP_NR_BASE + 425) },
	{ "statfs", (__SCMP_NR_BASE + 328) },
	{ "statfs64", (__SCMP_NR_BASE + 227) },
	{ "statx", (__SCMP_NR_BASE + 518) },
	{ "swapoff", (__SCMP_NR_BASE + 304) },
	{ "swapon", (__SCMP_NR_BASE + 322) },
	{ "symlink", (__SCMP_NR_BASE + 57) },
	{ "symlinkat", (__SCMP_NR_BASE + 459) },
	{ "sync", (__SCMP_NR_BASE + 36) },
	{ "sync_file_range", (__SCMP_NR_BASE + 469) },
	{ "syncfs", (__SCMP_NR_BASE + 500) },
	{ "sysfs", (__SCMP_NR_BASE + 254) },
	{ "sysinfo", (__SCMP_NR_BASE + 318) },
	{ "syslog", (__SCMP_NR_BASE + 310) },
	{ "tee", (__SCMP_NR_BASE + 470) },
	{ "tgkill", (__SCMP_NR_BASE + 424) },
	{ "timer_create", (__SCMP_NR_BASE + 414) },
	{ "timer_delete", (__SCMP_NR_BASE + 418) },
	{ "timer_getoverrun", (__SCMP_NR_BASE + 417) },
	{ "timer_gettime", (__SCMP_NR_BASE + 416) },
	{ "timer_settime", (__SCMP_NR_BASE + 415) },
	{ "timerfd_create", (__SCMP_NR_BASE + 481) },
	{ "timerfd_gettime", (__SCMP_NR_BASE + 483) },
	{ "timerfd_settime", (__SCMP_NR_BASE + 482) },
	{ "times", (__SCMP_NR_BASE + 323) },
	{ "tkill", (__SCMP_NR_BASE + 381) },
	{ "truncate", (__SCMP_NR_BASE + 129) },
	{ "umask", (__SCMP_NR_BASE + 60) },
	{ "umount", (__SCMP_NR_BASE + 22) },
	{ "uname", (__SCMP_NR_BASE + 339) },
	{ "unlink", (__SCMP_NR_BASE + 10) },
	{ "unlinkat", (__SCMP_NR_BASE + 456) },
	{ "unshare", (__SCMP_NR_BASE + 465) },
	{ "uselib", (__SCMP_NR_BASE + 313) },
	{ "userfaultfd", (__SCMP_NR_BASE + 171) },
	{ "ustat", (__SCMP_NR_BASE + 327) },
	{ "utimensat", (__SCMP_NR_BASE + 475) },
	{ "utimes", (__SCMP_NR_BASE + 363) },
	{ "vfork", (__SCMP_NR_BASE + 66) },
	{ "vhangup", (__SCMP_NR_BASE + 76) },
	{ "vmsplice", (__SCMP_NR_BASE + 471) },
	{ "wait4", (__SCMP_NR_BASE + 365) },
	{ "waitid", (__SCMP_NR_BASE + 438) },
	{ "write", (__SCMP_NR_BASE +  4) },
	{ "writev", (__SCMP_NR_BASE + 121) },
	{ NULL, __NR_SCMP_ERROR },
};

/**
 * Resolve a syscall name to a number
 * @param name the syscall name
 *
 * Resolve the given syscall name to the syscall number using the syscall table.
 * Returns the syscall number on success, including negative pseudo syscall
 * numbers; returns __NR_SCMP_ERROR on failure.
 *
 */
int sw_64_syscall_resolve_name(const char *name)
{
	unsigned int iter;
	const struct arch_syscall_def *table = sw_64_syscall_table;

	/* XXX - plenty of room for future improvement here */
	for (iter = 0; table[iter].name != NULL; iter++) {
		if (strcmp(name, table[iter].name) == 0)
			return table[iter].num;
	}

	return __NR_SCMP_ERROR; 
}

/**
 * Resolve a syscall number to a name
 * @param num the syscall number
 *
 * Resolve the given syscall number to the syscall name using the syscall table.
 * Returns a pointer to the syscall name string on success, including pseudo
 * syscall names; returns NULL on failure.
 *
 */
const char *sw_64_syscall_resolve_num(int num)
{
	unsigned int iter;
	const struct arch_syscall_def *table = sw_64_syscall_table;

	/* XXX - plenty of room for future improvement here */
	for (iter = 0; table[iter].num != __NR_SCMP_ERROR; iter++) {
		if (num == table[iter].num)
			return table[iter].name;
	}

	return NULL;
}

const char *sw_64_syscall_iterate_name(unsigned int spot)
{
	/* XXX - no safety checks here */
	return sw_64_syscall_table[spot].name;
}
const struct arch_syscall_def *sw_64_syscall_iterate(unsigned int spot)
{
	/* XXX - no safety checks here */
	return &sw_64_syscall_table[spot];
}